@@ -4,6 +4,7 @@ const Lang = imports.lang;
 const Gio = imports.gi.Gio;
 const St = imports.gi.St;
 
+const LoginManager = imports.misc.loginManager;
 const Main = imports.ui.main;
 const MessageTray = imports.ui.messageTray;
 const ShellMountOperation = imports.ui.shellMountOperation;
@@ -142,6 +143,8 @@ const AutorunManager = new Lang.Class({
     Name: 'AutorunManager',
 
     _init: function() {
+        this._loginManager = LoginManager.getLoginManager();
+
         this._volumeMonitor = Gio.VolumeMonitor.get();
 
         this._volumeMonitor.connect('mount-added',
@@ -176,7 +179,7 @@ const AutorunManager = new Lang.Class({
     _onMountAdded: function(monitor, mount) {
         // don't do anything if our session is not the currently
         // active one
-        if (!Main.automountManager.isSessionActive())
+        if (!this._loginManager.sessionActive)
             return;
 
         let discoverer = new ContentTypeDiscoverer(Lang.bind (this,
@@ -258,7 +261,8 @@ const AutorunResidentSource = new Lang.Class({
     Extends: MessageTray.Source,
 
     _init: function() {
-        this.parent(_("Removable Devices"), 'media-removable', St.IconType.FULLCOLOR);
+        this.parent(_("Removable Devices"), 'media-removable');
+        this.showInLockScreen = false;
 
         this._mounts = [];
 
