@@ -124,15 +124,19 @@ const DashItemContainer = new Lang.Class({
     },
 
     setLabelText: function(text) {
-        if (this.label == null)
+        if (this.label == null) {
             this.label = new St.Label({ style_class: 'dash-label'});
+            Main.layoutManager.addChrome(this.label);
+            this.label.hide();
+        }
 
         this.label.set_text(text);
-        Main.layoutManager.addChrome(this.label);
-        this.label.hide();
     },
 
     hideLabel: function () {
+        if (this.label == null)
+            return;
+
         Tweener.addTween(this.label,
                          { opacity: 0,
                            time: DASH_ITEM_LABEL_HIDE_TIME,
@@ -246,14 +250,15 @@ const ShowAppsIcon = new Lang.Class({
         this.toggleButton._delegate = this;
 
         this.setChild(this.toggleButton);
+        this.setHover(false);
+        this.toggleButton.label_actor = this.label;
     },
 
     _createIcon: function(size) {
         this._iconActor = new St.Icon({ icon_name: 'view-grid-symbolic',
+                                        icon_size: size,
                                         style_class: 'show-apps-icon',
-                                        track_hover: true,
-                                        icon_type: St.IconType.SYMBOLIC,
-                                        icon_size: size });
+                                        track_hover: true });
         return this._iconActor;
     },
 
@@ -261,6 +266,11 @@ const ShowAppsIcon = new Lang.Class({
         this.toggleButton.set_hover(hovered);
         if (this._iconActor)
             this._iconActor.set_hover(hovered);
+
+        if (hovered)
+            this.setLabelText(_("Remove from Favorites"));
+        else
+            this.setLabelText(_("Show Applications"));
     },
 
     // Rely on the dragged item being a favorite
@@ -326,6 +336,7 @@ const Dash = new Lang.Class({
 
         this._showAppsIcon = new ShowAppsIcon();
         this._showAppsIcon.icon.setIconSize(this.iconSize);
+        this._hookUpLabel(this._showAppsIcon);
 
         this.showAppsButton = this._showAppsIcon.toggleButton;
 
@@ -424,6 +435,17 @@ const Dash = new Lang.Class({
         Main.queueDeferredWork(this._workId);
     },
 
+    _hookUpLabel: function(item) {
+        item.child.connect('notify::hover', Lang.bind(this, function() {
+            this._onHover(item);
+        }));
+
+        Main.overview.connect('hiding', Lang.bind(this, function() {
+            this._labelShowing = false;
+            item.hideLabel();
+        }));
+    },
+
     _createAppItem: function(app) {
         let display = new AppDisplay.AppWellIcon(app,
                                                  { setSizeManually: true,
@@ -443,25 +465,14 @@ const Dash = new Lang.Class({
         item.setLabelText(app.get_name());
         // Override default AppWellIcon label_actor
         display.actor.label_actor = item.label;
-
-
         display.icon.setIconSize(this.iconSize);
-        display.actor.connect('notify::hover',
-                               Lang.bind(this, function() {
-                                   this._onHover(item, display)
-                               }));
-
-        Main.overview.connect('hiding',
-                              Lang.bind(this, function() {
-                                  this._labelShowing = false;
-                                  item.hideLabel();
-                              }));
+        this._hookUpLabel(item);
 
         return item;
     },
 
-    _onHover: function (item, display) {
-        if (display.actor.get_hover() && !display.isMenuUp) {
+    _onHover: function (item) {
+        if (item.child.get_hover() && !item.child._delegate.isMenuUp) {
             if (this._showLabelTimeoutId == 0) {
                 let timeout = this._labelShowing ? 0 : DASH_ITEM_HOVER_TIMEOUT;
                 this._showLabelTimeoutId = Mainloop.timeout_add(timeout,
