@@ -158,23 +158,32 @@ function loadExtension(extension) {
     _signals.emit('extension-state-changed', extension);
 }
 
-function unloadExtension(uuid) {
-    let extension = ExtensionUtils.extensions[uuid];
-    if (!extension)
-        return false;
-
+function unloadExtension(extension) {
     // Try to disable it -- if it's ERROR'd, we can't guarantee that,
     // but it will be removed on next reboot, and hopefully nothing
     // broke too much.
-    disableExtension(uuid);
+    disableExtension(extension.uuid);
 
     extension.state = ExtensionState.UNINSTALLED;
     _signals.emit('extension-state-changed', extension);
 
-    delete ExtensionUtils.extensions[uuid];
+    delete ExtensionUtils.extensions[extension.uuid];
     return true;
 }
 
+function reloadExtension(oldExtension) {
+    // Grab the things we'll need to pass to createExtensionObject
+    // to reload it.
+    let { uuid: uuid, dir: dir, type: type } = oldExtension;
+
+    // Then unload the old extension.
+    unloadExtension(oldExtension);
+
+    // Now, recreate the extension and load it.
+    let newExtension = ExtensionUtils.createExtensionObject(uuid, dir, type);
+    loadExtension(newExtension);
+}
+
 function initExtension(uuid) {
     let extension = ExtensionUtils.extensions[uuid];
     let dir = extension.dir;
