@@ -43,13 +43,11 @@ const XdndHandler = imports.ui.xdndHandler;
 const Util = imports.misc.util;
 
 const OVERRIDES_SCHEMA = 'org.gnome.shell.overrides';
-const DEFAULT_BACKGROUND_COLOR = new Clutter.Color();
-DEFAULT_BACKGROUND_COLOR.from_pixel(0x2266bbff);
+const DEFAULT_BACKGROUND_COLOR = Clutter.Color.from_pixel(0x2266bbff);
 
 let automountManager = null;
 let autorunManager = null;
 let panel = null;
-let hotCorners = [];
 let overview = null;
 let runDialog = null;
 let lookingGlass = null;
@@ -81,10 +79,6 @@ let _overridesSettings = null;
 let background = null;
 
 function createUserSession() {
-    // Load the calendar server. Note that we are careful about
-    // not loading any events until the user presses the clock
-    global.launch_calendar_server();
-
     telepathyClient = new TelepathyClient.Client();
     automountManager = new AutomountManager.AutomountManager();
     autorunManager = new AutorunManager.AutorunManager();
@@ -223,8 +217,7 @@ function start() {
 
     sessionMode.createSession();
 
-    panel.startStatusArea();
-
+    panel.init();
     layoutManager.init();
     keyboard.init();
     overview.init();
@@ -233,11 +226,6 @@ function start() {
         global.screen.override_workspace_layout(Meta.ScreenCorner.TOPLEFT,
                                                 false, -1, 1);
 
-    if (sessionMode.allowExtensions) {
-        ExtensionDownloader.init();
-        ExtensionSystem.loadExtensions();
-    }
-
     if (sessionMode.hasRunDialog) {
         Meta.keybindings_set_custom_handler('panel-run-dialog', function() {
            getRunDialog().open();
@@ -286,6 +274,11 @@ function start() {
     global.screen.connect('restacked', _windowsRestacked);
 
     _nWorkspacesChanged();
+
+    if (sessionMode.allowExtensions) {
+        ExtensionDownloader.init();
+        ExtensionSystem.loadExtensions();
+    }
 }
 
 let _workspaces = [];
@@ -509,9 +502,6 @@ function loadTheme() {
 
     let theme = new St.Theme ({ application_stylesheet: cssStylesheet });
 
-    if (sessionMode.extraStylesheet)
-        theme.load_stylesheet(sessionMode.extraStylesheet);
-
     if (previousTheme) {
         let customStylesheets = previousTheme.get_custom_stylesheets();
 
