@@ -256,6 +256,7 @@ const NotificationDaemon = new Lang.Class({
             Mainloop.idle_add(Lang.bind(this,
                                         function () {
                                             this._emitNotificationClosed(id, NotificationClosedReason.DISMISSED);
+                                            return false;
                                         }));
             return invocation.return_value(GLib.Variant.new('(u)', [id]));
         }
@@ -356,7 +357,6 @@ const NotificationDaemon = new Lang.Class({
 
         let gicon = this._iconForNotificationData(icon, hints);
         let iconActor = new St.Icon({ gicon: gicon,
-                                      icon_type: St.IconType.FULLCOLOR,
                                       icon_size: MessageTray.NOTIFICATION_ICON_SIZE });
 
         if (notification == null) {
@@ -583,18 +583,12 @@ const Source = new Lang.Class({
             this.notifications.length > 0)
             return false;
 
-        if (Main.overview.visible) {
-            // We can't just connect to Main.overview's 'hidden' signal,
-            // because it's emitted *before* it calls popModal()...
-            let id = global.connect('notify::stage-input-mode', Lang.bind(this,
-                function () {
-                    global.disconnect(id);
-                    this.trayIcon.click(event);
-                }));
-            Main.overview.hide();
-        } else {
+        let id = global.connect('notify::stage-input-mode', Lang.bind(this, function () {
+            global.disconnect(id);
             this.trayIcon.click(event);
-        }
+        }));
+
+        Main.overview.hide();
         return true;
     },
 
