@@ -134,6 +134,7 @@ const PopupBaseMenuItem = new Lang.Class({
 
         this.sensitive = sensitive;
         this.actor.reactive = sensitive;
+        this.actor.can_focus = sensitive;
 
         this.emit('sensitive-changed', sensitive);
     },
@@ -717,7 +718,8 @@ const Switch = new Lang.Class({
 
     _init: function(state) {
         this.actor = new St.Bin({ style_class: 'toggle-switch',
-                                  accessible_role: Atk.Role.CHECK_BOX});
+                                  accessible_role: Atk.Role.CHECK_BOX,
+                                  can_focus: true });
         // Translators: this MUST be either "toggle-switch-us"
         // (for toggle switches containing the English words
         // "ON" and "OFF") or "toggle-switch-intl" (for toggle
@@ -1050,14 +1052,17 @@ const PopupMenuBase = new Lang.Class({
 
         if (menuItem instanceof PopupMenuSection) {
             this._connectSubMenuSignals(menuItem, menuItem);
-            menuItem._closingId = this.connect('open-state-changed',
+            menuItem._parentOpenStateChangedId = this.connect('open-state-changed',
                 function(self, open) {
-                    if (!open)
-                        menuItem.close(BoxPointer.PopupAnimation.FADE);
+                    if (open)
+                        menuItem.open();
+                    else
+                        menuItem.close();
                 });
             menuItem.connect('destroy', Lang.bind(this, function() {
                 menuItem.disconnect(menuItem._subMenuActivateId);
                 menuItem.disconnect(menuItem._subMenuActiveChangeId);
+                this.disconnect(menuItem._parentOpenStateChangedId);
 
                 this.length--;
             }));
@@ -1438,7 +1443,7 @@ const PopupMenuSection = new Lang.Class({
 
     // deliberately ignore any attempt to open() or close(), but emit the
     // corresponding signal so children can still pick it up
-    open: function(animate) { this.emit('open-state-changed', true); },
+    open: function() { this.emit('open-state-changed', true); },
     close: function() { this.emit('open-state-changed', false); },
 
     destroy: function() {
@@ -1876,7 +1881,7 @@ const RemoteMenu = new Lang.Class({
             }));
         }
 
-        item.actor.reactive = action.enabled;
+        item.actor.reactive = item.actor.can_focus = action.enabled;
 
         destroyId = item.connect('destroy', Lang.bind(this, function() {
             item.disconnect(destroyId);
@@ -2008,7 +2013,7 @@ const RemoteMenu = new Lang.Class({
         if (action.items.length) {
             for (let i = 0; i < action.items.length; i++) {
                 let item = action.items[i];
-                item.actor.reactive = action.enabled;
+                item.actor.reactive = item.actor.can_focus = action.enabled;
             }
         }
     }
