@@ -1,13 +1,16 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
+const Cairo = imports.cairo;
 const Clutter = imports.gi.Clutter;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GnomeDesktop = imports.gi.GnomeDesktop;
 const Lang = imports.lang;
+const Mainloop = imports.mainloop;
 const Meta = imports.gi.Meta;
 const Signals = imports.signals;
 const St = imports.gi.St;
+const TweenerEquations = imports.tweener.equations;
 
 const GnomeSession = imports.misc.gnomeSession;
 const Layout = imports.ui.layout;
@@ -25,6 +28,11 @@ const CURTAIN_SLIDE_TIME = 0.5;
 // the slide up automatically
 const ARROW_DRAG_TRESHOLD = 0.1;
 
+// Parameters for the arrow animation
+const N_ARROWS = 3;
+const ARROW_ANIMATION_TIME = 0.6;
+const ARROW_ANIMATION_PEAK_OPACITY = 0.4;
+
 // The distance in px that the lock screen will move to when pressing
 // a key that has no effect in the lock screen (bumping it)
 const BUMP_SIZE = 25;
@@ -159,8 +167,9 @@ const NotificationsBox = new Lang.Class({
     },
 
     _summaryItemAdded: function(tray, item, dontUpdateVisibility) {
-        // Ignore transient sources
-        if (item.source.isTransient)
+        // Ignore transient sources, or sources explicitly marked not to show
+        // in the lock screen
+        if (item.source.isTransient || !item.source.showInLockScreen)
             return;
 
         let obj = {
@@ -174,8 +183,9 @@ const NotificationsBox = new Lang.Class({
         };
 
         if (obj.resident) {
+            this._residentNotificationBox.add(item.notificationStackWidget);
+            item.closeButtonVisible = false;
             item.prepareNotificationStackForShowing();
-            this._residentNotificationBox.add(item.notificationStackView);
         } else {
             [obj.sourceBox, obj.countLabel] = this._makeNotificationSource(item.source);
             this._persistentNotificationBox.add(obj.sourceBox, { x_fill: false, x_align: St.Align.MIDDLE });
@@ -220,7 +230,8 @@ const NotificationsBox = new Lang.Class({
 
         if (obj.resident && !itemShouldBeResident) {
             // make into a regular item
-            this._residentNotificationBox.remove_actor(obj.item.notificationStackView);
+            obj.item.doneShowingNotificationStack();
+            this._residentNotificationBox.remove_actor(obj.item.notificationStackWidget);
 
             [obj.sourceBox, obj.countLabel] = this._makeNotificationSource(obj.source);
             this._persistentNotificationBox.add(obj.sourceBox);
@@ -230,8 +241,9 @@ const NotificationsBox = new Lang.Class({
             obj.sourceBox = obj.countLabel = null;
             obj.resident = true;
 
+            this._residentNotificationBox.add(obj.item.notificationStackWidget);
+            obj.item.closeButtonVisible = false;
             obj.item.prepareNotificationStackForShowing();
-            this._residentNotificationBox.add(obj.item.notificationStackView);
         } else {
             // just update the counter
             let count = obj.source.unseenCount;
@@ -253,8 +265,8 @@ const NotificationsBox = new Lang.Class({
 
     _removeItem: function(obj) {
         if (obj.resident) {
-            this._residentNotificationBox.remove_actor(obj.item.notificationStackView);
             obj.item.doneShowingNotificationStack();
+            this._residentNotificationBox.remove_actor(obj.item.notificationStackWidget);
         } else {
             obj.sourceBox.destroy();
         }
@@ -265,6 +277,62 @@ const NotificationsBox = new Lang.Class({
     },
 });
 
+const Arrow = new Lang.Class({
+    Name: 'Arrow',
+    Extends: St.Bin,
+
+    _init: function(params) {
+        this.parent(params);
+        this.x_fill = this.y_fill = true;
+        this.set_offscreen_redirect(Clutter.OffscreenRedirect.ALWAYS);
+
+        this._drawingArea = new St.DrawingArea();
+        this._drawingArea.connect('repaint', Lang.bind(this, this._drawArrow));
+        this.child = this._drawingArea;
+
+        this._shadowHelper = null;
+        this._shadowWidth = this._shadowHeight = 0;
+    },
+
+    _drawArrow: function(arrow) {
+        let cr = arrow.get_context();
+        let [w, h] = arrow.get_surface_size();
+        let node = this.get_theme_node();
+        let thickness = node.get_length('-arrow-thickness');
+
+        Clutter.cairo_set_source_color(cr, node.get_foreground_color());
+
+        cr.setLineCap(Cairo.LineCap.ROUND);
+        cr.setLineWidth(thickness);
+
+        cr.moveTo(thickness / 2, h - thickness / 2);
+        cr.lineTo(w/2, thickness);
+        cr.lineTo(w - thickness / 2, h - thickness / 2);
+        cr.stroke();
+    },
+
+    vfunc_style_changed: function() {
+        let node = this.get_theme_node();
+        this._shadow = node.get_shadow('-arrow-shadow');
+        if (this._shadow)
+            this._shadowHelper = St.ShadowHelper.new(this._shadow);
+        else
+            this._shadowHelper = null;
+    },
+
+    vfunc_paint: function() {
+        if (this._shadowHelper) {
+            this._shadowHelper.update(this._drawingArea);
+
+            let allocation = this._drawingArea.get_allocation_box();
+            let paintOpacity = this._drawingArea.get_paint_opacity();
+            this._shadowHelper.paint(allocation, paintOpacity);
+        }
+
+        this._drawingArea.paint();
+    }
+});
+
 /**
  * To test screen shield, make sure to kill gnome-screensaver.
  *
@@ -281,6 +349,7 @@ const ScreenShield = new Lang.Class({
     _init: function() {
         this.actor = Main.layoutManager.screenShieldGroup;
 
+        this._lockScreenState = MessageTray.State.HIDDEN;
         this._lockScreenGroup = new St.Widget({ x_expand: true,
                                                 y_expand: true,
                                                 reactive: true,
@@ -289,6 +358,8 @@ const ScreenShield = new Lang.Class({
                                               });
         this._lockScreenGroup.connect('key-release-event',
                                       Lang.bind(this, this._onLockScreenKeyRelease));
+        this._lockScreenGroup.connect('scroll-event',
+                                      Lang.bind(this, this._onLockScreenScroll));
 
         this._lockScreenContents = new St.Widget({ layout_manager: new Clutter.BinLayout(),
                                                    name: 'lockScreenContents' });
@@ -298,19 +369,20 @@ const ScreenShield = new Lang.Class({
         this._lockScreenGroup.add_actor(this._background);
         this._lockScreenGroup.add_actor(this._lockScreenContents);
 
-        // FIXME: build the rest of the lock screen here
+        this._arrowContainer = new St.BoxLayout({ style_class: 'screen-shield-arrows',
+                                                  vertical: true,
+                                                  x_align: Clutter.ActorAlign.CENTER,
+                                                  y_align: Clutter.ActorAlign.END,
+                                                  // HACK: without these, ClutterBinLayout
+                                                  // ignores alignment properties on the actor
+                                                  x_expand: true,
+                                                  y_expand: true });
 
-        this._arrow = new St.DrawingArea({ style_class: 'arrow',
-                                           reactive: true,
-                                           x_align: Clutter.ActorAlign.CENTER,
-                                           y_align: Clutter.ActorAlign.END,
-                                           // HACK: without these, ClutterBinLayout
-                                           // ignores alignment properties on the actor
-                                           x_expand: true,
-                                           y_expand: true
-                                         });
-        this._arrow.connect('repaint', Lang.bind(this, this._drawArrow));
-        this._lockScreenContents.add_actor(this._arrow);
+        for (let i = 0; i < N_ARROWS; i++) {
+            let arrow = new Arrow({ opacity: 0 });
+            this._arrowContainer.add_actor(arrow);
+        }
+        this._lockScreenContents.add_actor(this._arrowContainer);
 
         let dragArea = new Clutter.Rect({ origin: new Clutter.Point({ x: 0, y: -global.screen_height, }),
                                           size: new Clutter.Size({ width: global.screen_width,
@@ -364,29 +436,60 @@ const ScreenShield = new Lang.Class({
             return true;
         }
 
-        // If the dialog is created, but hasn't received focus yet,
-        // the lock screen could be still focused, so bumping would
-        // make the curtain fall again.
-        if (!this._dialog)
+        // Don't bump if the lock screen is not showing or is
+        // animating, as the bump overrides the animation and would
+        // remove any onComplete handler
+        if (this._lockScreenState == MessageTray.State.SHOWN)
             this._bumpLockScreen();
         return true;
     },
 
-    _drawArrow: function() {
-        let cr = this._arrow.get_context();
-        let [w, h] = this._arrow.get_surface_size();
-        let node = this._arrow.get_theme_node();
+    _onLockScreenScroll: function(actor, event) {
+        if (this._lockScreenState != MessageTray.State.SHOWN)
+            return false;
 
-        Clutter.cairo_set_source_color(cr, node.get_foreground_color());
+        let delta = 0;
+        if (event.get_scroll_direction() == Clutter.ScrollDirection.UP)
+            delta = 5;
+        else if (event.get_scroll_direction() == Clutter.ScrollDirection.SMOOTH)
+            delta = Math.max(0, event.get_scroll_delta()[0]);
 
-        cr.moveTo(0, h);
-        cr.lineTo(w/2, 0);
-        cr.lineTo(w, h);
-        cr.fill();
+        this._lockScreenScrollCounter += delta;
+
+        // 7 standard scrolls to lift up
+        if (this._lockScreenScrollCounter > 35) {
+            this._ensureUnlockDialog();
+            this._hideLockScreen(0);
+        }
+
+        return true;
+    },
+
+    _animateArrows: function() {
+        let arrows = this._arrowContainer.get_children();
+        let unitaryDelay = ARROW_ANIMATION_TIME / (arrows.length + 1);
+        let maxOpacity = 255 * ARROW_ANIMATION_PEAK_OPACITY;
+        for (let i = 0; i < arrows.length; i++) {
+            arrows.opacity = 0;
+            Tweener.addTween(arrows[i],
+                             { opacity: 0,
+                               delay: unitaryDelay * (N_ARROWS - (i + 1)),
+                               time: ARROW_ANIMATION_TIME,
+                               transition: function(t, b, c, d) {
+                                 if (t < d/2)
+                                     return TweenerEquations.easeOutQuad(t, 0, maxOpacity, d/2);
+                                 else
+                                     return TweenerEquations.easeInQuad(t - d/2, maxOpacity, -maxOpacity, d/2);
+                               }
+                             });
+        }
+
+        return true;
     },
 
     _onDragBegin: function() {
         Tweener.removeTweens(this._lockScreenGroup);
+        this._lockScreenState = MessageTray.State.HIDING;
         this._ensureUnlockDialog();
     },
 
@@ -405,8 +508,10 @@ const ScreenShield = new Lang.Class({
                                time: time,
                                transition: 'linear',
                                onComplete: function() {
-                                   this.fixed_position_set = false;
-                               }
+                                   this._lockScreenGroup.fixed_position_set = false;
+                                   this._lockScreenState = MessageTray.State.SHOWN;
+                               },
+                               onCompleteScope: this,
                              });
 
             // If we have a unlock dialog, cancel it
@@ -470,6 +575,8 @@ const ScreenShield = new Lang.Class({
     },
 
     _hideLockScreen: function(animate) {
+        this._lockScreenState = MessageTray.State.HIDING;
+
         if (animate) {
             // Tween the lock screen out of screen
             // try to use the same speed regardless of original position
@@ -480,13 +587,21 @@ const ScreenShield = new Lang.Class({
                              { y: -h,
                                time: time,
                                transition: 'linear',
-                               onComplete: function() { this.hide(); }
+                               onComplete: function() {
+                                   this._lockScreenHidden();
+                               },
+                               onCompleteScope: this,
                              });
         } else {
-            this._lockScreenGroup.hide();
+            this._lockScreenHidden();
         }
     },
 
+    _lockScreenHidden: function() {
+        this._lockScreenState = MessageTray.State.HIDDEN;
+        this._lockScreenGroup.hide();
+    },
+
     _ensureUnlockDialog: function() {
         if (!this._dialog) {
             [this._dialog, this._keepDialog] = Main.sessionMode.createUnlockDialog(this._lockDialogGroup);
@@ -530,6 +645,7 @@ const ScreenShield = new Lang.Class({
 
     _resetLockScreen: function(animate) {
         this._lockScreenGroup.show();
+        this._lockScreenState = MessageTray.State.SHOWING;
 
         if (animate) {
             this._lockScreenGroup.y = -global.screen_height;
@@ -539,8 +655,7 @@ const ScreenShield = new Lang.Class({
                                time: SHORT_FADE_TIME,
                                transition: 'linear',
                                onComplete: function() {
-                                   this._lockScreenGroup.fixed_position_set = false;
-                                   this.emit('lock-screen-shown');
+                                   this._lockScreenShown();
                                },
                                onCompleteScope: this
                              });
@@ -552,14 +667,26 @@ const ScreenShield = new Lang.Class({
                                time: SHORT_FADE_TIME,
                                transition: 'easeOutQuad' });
         } else {
-            this._lockScreenGroup.fixed_position_set = false;
             this._lockDialogGroup.opacity = 255;
-            this.emit('lock-screen-shown');
+            this._lockScreenShown();
         }
 
         this._lockScreenGroup.grab_key_focus();
     },
 
+    _lockScreenShown: function() {
+        if (this._arrowAnimationId)
+            Mainloop.source_remove(this._arrowAnimationId);
+        this._arrowAnimationId = Mainloop.timeout_add(6000, Lang.bind(this, this._animateArrows));
+        this._animateArrows();
+
+        this._lockScreenState = MessageTray.State.SHOWN;
+        this._lockScreenGroup.fixed_position_set = false;
+        this._lockScreenScrollCounter = 0;
+
+        this.emit('lock-screen-shown');
+    },
+
     // Some of the actors in the lock screen are heavy in
     // resources, so we only create them when needed
     _prepareLockScreen: function() {
@@ -595,6 +722,11 @@ const ScreenShield = new Lang.Class({
 
         this._lockScreenContentsBox.destroy();
 
+        if (this._arrowAnimationId) {
+            Mainloop.source_remove(this._arrowAnimationId);
+            this._arrowAnimationId = 0;
+        }
+
         this._hasLockScreen = false;
     },
 
