@@ -2,36 +2,13 @@
 
 const Lang = imports.lang;
 
-const Config = imports.misc.config;
 const Main = imports.ui.main;
 const Params = imports.misc.params;
 
-
-const STANDARD_STATUS_AREA_SHELL_IMPLEMENTATION = {
-    'a11y': imports.ui.status.accessibility.ATIndicator,
-    'volume': imports.ui.status.volume.Indicator,
-    'battery': imports.ui.status.power.Indicator,
-    'keyboard': imports.ui.status.keyboard.InputSourceIndicator,
-    'userMenu': imports.ui.userMenu.UserMenuButton
-};
-
-if (Config.HAVE_BLUETOOTH)
-    STANDARD_STATUS_AREA_SHELL_IMPLEMENTATION['bluetooth'] =
-        imports.ui.status.bluetooth.Indicator;
-
-try {
-    STANDARD_STATUS_AREA_SHELL_IMPLEMENTATION['network'] =
-        imports.ui.status.network.NMApplet;
-} catch(e) {
-    log('NMApplet is not supported. It is possible that your NetworkManager version is too old');
-}
-
-
 const DEFAULT_MODE = 'user';
 
 const _modes = {
     'gdm': { hasOverview: false,
-             hasAppMenu: false,
              showCalendarEvents: false,
              allowSettings: false,
              allowExtensions: false,
@@ -40,24 +17,15 @@ const _modes = {
              hasWorkspaces: false,
              createSession: Main.createGDMSession,
              createUnlockDialog: Main.createGDMLoginDialog,
-             extraStylesheet: null,
-             statusArea: {
-                 order: [
-                     'a11y', 'display', 'keyboard',
-                     'volume', 'battery', 'powerMenu'
-                 ],
-                 implementation: {
-                     'a11y': imports.ui.status.accessibility.ATIndicator,
-                     'volume': imports.ui.status.volume.Indicator,
-                     'battery': imports.ui.status.power.Indicator,
-                     'keyboard': imports.ui.status.keyboard.InputSourceIndicator,
-                     'powerMenu': imports.gdm.powerMenu.PowerMenuButton
-                 }
+             panel: {
+                 left: [],
+                 center: ['dateMenu'],
+                 right: ['a11y', 'display', 'keyboard',
+                         'volume', 'battery', 'lockScreen', 'powerMenu']
              }
            },
 
     'initial-setup': { hasOverview: false,
-                       hasAppMenu: false,
                        showCalendarEvents: false,
                        allowSettings: false,
                        allowExtensions: false,
@@ -65,21 +33,14 @@ const _modes = {
                        hasRunDialog: false,
                        hasWorkspaces: false,
                        createSession: Main.createInitialSetupSession,
-                       extraStylesheet: null,
-                       statusArea: {
-                           order: [
-                               'a11y', 'keyboard', 'volume'
-                           ],
-                           implementation: {
-                               'a11y': imports.ui.status.accessibility.ATIndicator,
-                               'keyboard': imports.ui.status.keyboard.XKBIndicator,
-                               'volume': imports.ui.status.volume.Indicator
-                        }
-                }
-           },
+                       panel: {
+                           left: [],
+                           center: ['dateMenu'],
+                           right: ['a11y', 'keyboard', 'volume', 'lockScreen']
+                       }
+                     },
 
     'user': { hasOverview: true,
-              hasAppMenu: true,
               showCalendarEvents: true,
               allowSettings: true,
               allowExtensions: true,
@@ -88,13 +49,11 @@ const _modes = {
               hasWorkspaces: true,
               createSession: Main.createUserSession,
               createUnlockDialog: Main.createSessionUnlockDialog,
-              extraStylesheet: null,
-              statusArea: {
-                  order: [
-                      'input-method', 'a11y', 'keyboard', 'volume', 'bluetooth',
-                      'network', 'battery', 'userMenu'
-                  ],
-                  implementation: STANDARD_STATUS_AREA_SHELL_IMPLEMENTATION
+              panel: {
+                  left: ['activities', 'appMenu'],
+                  center: ['dateMenu'],
+                  right: ['a11y', 'keyboard', 'volume', 'bluetooth',
+                          'network', 'battery', 'lockScreen', 'userMenu']
               }
             }
 };
