@@ -1,6 +1,7 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
+const Gio = imports.gi.Gio;
 const Lang = imports.lang;
 const NetworkManager = imports.gi.NetworkManager;
 const NMClient = imports.gi.NMClient;
@@ -121,7 +122,7 @@ const NMNetworkMenuItem = new Lang.Class({
         this._secureIcon = new St.Icon({ style_class: 'popup-menu-icon' });
         if (this.bestAP._secType != NMAccessPointSecurity.UNKNOWN &&
             this.bestAP._secType != NMAccessPointSecurity.NONE)
-            this._secureIcon.icon_name = 'network-wireless-encrypted';
+            this._secureIcon.icon_name = 'network-wireless-encrypted-symbolic';
         this._icons.add_actor(this._secureIcon);
     },
 
@@ -132,9 +133,9 @@ const NMNetworkMenuItem = new Lang.Class({
 
     _getIcon: function() {
         if (this.bestAP.mode == NM80211Mode.ADHOC)
-            return 'network-workgroup';
+            return 'network-workgroup-symbolic';
         else
-            return 'network-wireless-signal-' + signalToIcon(this.bestAP.strength);
+            return 'network-wireless-signal-' + signalToIcon(this.bestAP.strength) + '-symbolic';
     }
 });
 
@@ -167,15 +168,14 @@ const NMWiredSectionTitleMenuItem = new Lang.Class({
 
         let newState = this._switch.state;
 
-        // Immediately reset the switch to false, it will be updated appropriately
-        // by state-changed signals in devices (but fixes the VPN not being in sync
-        // if the ActiveConnection object is never seen by libnm-glib)
-        this._switch.setToggleState(false);
-
+        let ok;
         if (newState)
-            this._device.activate();
+            ok = this._device.activate();
         else
-            this._device.deactivate();
+            ok = this._device.deactivate();
+
+        if (!ok)
+            this._switch.setToggleState(false);
     }
 });
 
@@ -272,11 +272,14 @@ const NMDevice = new Lang.Class({
         if (this.device) {
             this.statusItem = new PopupMenu.PopupSwitchMenuItem(this._getDescription(), this.connected, { style_class: 'popup-subtitle-menu-item' });
             this._statusChanged = this.statusItem.connect('toggled', Lang.bind(this, function(item, state) {
+                let ok;
                 if (state)
-                    this.activate();
+                    ok = this.activate();
                 else
-                    this.deactivate();
-                this.emit('enabled-changed');
+                    ok = this.deactivate();
+
+                if (!ok)
+                    item.setToggleState(!state);
             }));
 
             this._updateStatusItem();
@@ -314,22 +317,35 @@ const NMDevice = new Lang.Class({
 
     deactivate: function() {
         this.device.disconnect(null);
+        return true;
     },
 
     activate: function() {
         if (this._activeConnection)
             // nothing to do
-            return;
+            return true;
 
-        // pick the most recently used connection and connect to that
-        // or if no connections ever set, create an automatic one
-        if (this._connections.length > 0) {
+        // If there is only one connection available, use that
+        // Otherwise, if no connection is currently configured,
+        // try automatic configuration (or summon the config dialog)
+        if (this._connections.length == 1) {
             this._client.activate_connection(this._connections[0].connection, this.device, null, null);
-        } else if (this._autoConnectionName) {
-            let connection = this._createAutomaticConnection();
-            if (connection)
-                this._client.add_and_activate_connection(connection, this.device, null, null);
+            return true;
+        } else if (this._connections.length == 0) {
+            return this._activateAutomaticConnection();
         }
+
+        return false;
+    },
+
+    _activateAutomaticConnection: function() {
+        let connection = this._createAutomaticConnection();
+        if (connection) {
+            this._client.add_and_activate_connection(connection, this.device, null, null);
+            return true;
+        }
+
+        return false;
     },
 
     get connected() {
@@ -760,7 +776,7 @@ const NMDeviceModem = new Lang.Class({
     },
 
     _getSignalIcon: function() {
-        return 'network-cellular-signal-' + signalToIcon(this.mobileDevice.signal_quality);
+        return 'network-cellular-signal-' + signalToIcon(this.mobileDevice.signal_quality) + '-symbolic';
     },
 
     _createSection: function() {
@@ -786,13 +802,13 @@ const NMDeviceModem = new Lang.Class({
         this.parent();
     },
 
-    _createAutomaticConnection: function() {
+    _activateAutomaticConnection: function() {
         // Mobile wizard is too complex for the shell UI and
         // is handled by the network panel
         Util.spawn(['gnome-control-center', 'network',
                     'connect-3g', this.device.get_path()]);
-        return null;
-    }
+        return true;
+    },
 });
 
 const NMDeviceBluetooth = new Lang.Class({
@@ -821,6 +837,16 @@ const NMDeviceBluetooth = new Lang.Class({
         return connection;
     },
 
+    _activateAutomaticConnection: function() {
+        // FIXME: DUN devices are configured like modems, so
+        // we need to spawn the mobile wizard
+        // but the network panel doesn't support bluetooth at the moment
+        // so we just create an empty connection and hope
+        // that this phone supports PAN
+
+        return this.parent();
+    },
+
     _makeConnectionName: function(device) {
         let name = device.name;
         if (name)
@@ -1041,44 +1067,13 @@ const NMDeviceWireless = new Lang.Class({
     activate: function() {
         if (this._activeConnection)
             // nothing to do
-            return;
+            return true;
 
-        // among all visible networks, pick the last recently used connection
-        let best = null;
-        let bestApObj = null;
-        let bestTime = 0;
-        for (let i = 0; i < this._networks.length; i++) {
-            let apObj = this._networks[i];
-            for (let j = 0; j < apObj.connections.length; j++) {
-                let connection = apObj.connections[j];
-                if (connection._timestamp > bestTime) {
-                    best = connection;
-                    bestTime = connection._timestamp;
-                    bestApObj = apObj;
-                }
-            }
-        }
-
-        if (best) {
-            for (let i = 0; i < bestApObj.accessPoints.length; i++) {
-                let ap = bestApObj.accessPoints[i];
-                if (ap.connection_valid(best)) {
-                    this._client.activate_connection(best, this.device, ap.dbus_path, null);
-                    break;
-                }
-            }
-            return;
-        }
-
-        // XXX: what else to do?
-        // for now, just pick a random network
-        // (this function is called in a corner case anyway, that is, only when
-        // the user toggles the switch and has more than one wireless device)
-        if (this._networks.length > 0) {
-            let connection = this._createAutomaticConnection(this._networks[0]);
-            let accessPoints = this._networks[0].accessPoints;
-            this._client.add_and_activate_connection(connection, this.device, accessPoints[0].dbus_path, null);
-        }
+        // All possible policy we can have here is just broken
+        // NM autoconnects when wifi devices are enabled, and if it
+        // didn't, there is a good reason
+        // User, pick a connection from the list, thank you
+        return false;
     },
 
     _notifySsidCb: function(accessPoint) {
@@ -1468,7 +1463,7 @@ const NMDeviceWireless = new Lang.Class({
                                                                { reactive: false });
         else
             this._activeConnectionItem = new PopupMenu.PopupImageMenuItem(title,
-                                                                          'network-wireless-connected',
+                                                                          'network-wireless-connected-symbolic',
                                                                           { reactive: false });
         this._activeConnectionItem.setShowDot(true);
     },
@@ -1564,26 +1559,15 @@ const NMDeviceWireless = new Lang.Class({
 
 const NMApplet = new Lang.Class({
     Name: 'NMApplet',
-    Extends: PanelMenu.Button,
+    Extends: PanelMenu.SystemStatusButton,
 
     _init: function() {
-        this.parent(0.0, _('Network'));
+        this.parent('network-offline', _('Network'));
 
-        this._box = new St.BoxLayout({ name: 'networkMenu' });
-        this.actor.add_actor (this._box);
-        this.actor.add_style_class_name('panel-status-button');
-
-        this._primaryIcon = new St.Icon({ icon_name: 'network-offline',
-                                          icon_type: St.IconType.SYMBOLIC,
-                                          style_class: 'system-status-icon' });
-        this._box.add_actor(this._primaryIcon);
-
-        this._secondaryIcon = new St.Icon({ icon_name: 'network-vpn',
-                                            icon_type: St.IconType.SYMBOLIC,
-                                            style_class: 'system-status-icon',
-                                            visible: false });
-        this._box.add_actor(this._secondaryIcon);
+        this.secondaryIcon = this.addIcon(new Gio.ThemedIcon({ name: 'network-vpn-symbolic' }));
+        this.secondaryIcon.hide();
 
+        this._isLocked = false;
         this._client = NMClient.Client.new();
 
         this._statusSection = new PopupMenu.PopupMenuSection();
@@ -1691,24 +1675,15 @@ const NMApplet = new Lang.Class({
         }));
     },
 
-    setIcon: function(iconName) {
-        this._primaryIcon.icon_name = iconName;
-    },
-
     setLockedState: function(locked) {
-        // FIXME: more design discussion is needed before we can
-        // expose part of this menu
-
-        if (locked)
-            this.menu.close();
-        this.actor.reactive = !locked;
+        this._isLocked = locked;
+        this._syncNMState();
     },
 
     _ensureSource: function() {
         if (!this._source) {
             this._source = new MessageTray.Source(_("Network Manager"),
-                                                  'network-transmit-receive',
-                                                  St.IconType.SYMBOLIC);
+                                                  'network-transmit-receive');
 
             this._source.connect('destroy', Lang.bind(this, function() {
                 this._source = null;
@@ -1779,9 +1754,7 @@ const NMApplet = new Lang.Class({
         this._ensureSource();
 
         let icon = new St.Icon({ icon_name: iconName,
-                                 icon_type: St.IconType.SYMBOLIC,
-                                 icon_size: this._source.ICON_SIZE
-                               });
+                                 icon_size: MessageTray.NOTIFICATION_ICON_SIZE });
         device._notification = new MessageTray.Notification(this._source, title, text,
                                                             { icon: icon });
         device._notification.setUrgency(urgency);
@@ -1798,7 +1771,7 @@ const NMApplet = new Lang.Class({
         wrapper._activationFailedId = wrapper.connect('activation-failed', Lang.bind(this, function(device, reason) {
             // XXX: nm-applet has no special text depending on reason
             // but I'm not sure of this generic message
-            this._notifyForDevice(device, 'network-error',
+            this._notifyForDevice(device, 'network-error-symbolic',
                                   _("Connection failed"),
                                   _("Activation of network connection failed"),
                                   MessageTray.Urgency.HIGH);
@@ -1823,7 +1796,6 @@ const NMApplet = new Lang.Class({
         let wrapperClass = this._dtypes[device.get_device_type()];
         if (wrapperClass) {
             let wrapper = this._makeWrapperDevice(wrapperClass, device);
-
             let section = this._devices[wrapper.category].section;
             let devices = this._devices[wrapper.category].devices;
 
@@ -2090,16 +2062,11 @@ const NMApplet = new Lang.Class({
     },
 
     _syncNMState: function() {
-        if (!this._client.manager_running) {
-            log('NetworkManager is not running, hiding...');
-            this.menu.close();
-            this.actor.hide();
-            return;
-        } else
-            this.actor.show();
+        this.mainIcon.visible = this._client.manager_running;
+        this.actor.visible = this.mainIcon.visible && !this._isLocked;
 
         if (!this._client.networking_enabled) {
-            this.setIcon('network-offline');
+            this.setIcon('network-offline-symbolic');
             this._hideDevices();
             this._statusItem.label.text = _("Networking is disabled");
             this._statusSection.actor.show();
@@ -2117,22 +2084,22 @@ const NMApplet = new Lang.Class({
         let hasMobileIcon = false;
 
         if (!mc) {
-            this.setIcon('network-offline');
+            this.setIcon('network-offline-symbolic');
         } else if (mc.state == NetworkManager.ActiveConnectionState.ACTIVATING) {
             switch (mc._section) {
             case NMConnectionCategory.WWAN:
-                this.setIcon('network-cellular-acquiring');
+                this.setIcon('network-cellular-acquiring-symbolic');
                 break;
             case NMConnectionCategory.WIRELESS:
-                this.setIcon('network-wireless-acquiring');
+                this.setIcon('network-wireless-acquiring-symbolic');
                 break;
             case NMConnectionCategory.WIRED:
-                this.setIcon('network-wired-acquiring');
+                this.setIcon('network-wired-acquiring-symbolic');
                 break;
             default:
                 // fallback to a generic connected icon
                 // (it could be a private connection of some other user)
-                this.setIcon('network-wired-acquiring');
+                this.setIcon('network-wired-acquiring-symbolic');
             }
         } else {
             let dev;
@@ -2147,17 +2114,17 @@ const NMApplet = new Lang.Class({
                             log('An active wireless connection, in infrastructure mode, involves no access point?');
                             break;
                         }
-                        this.setIcon('network-wireless-connected');
+                        this.setIcon('network-wireless-connected-symbolic');
                     } else {
                         if (this._activeAccessPoint != ap) {
                             if (this._accessPointUpdateId)
                                 this._activeAccessPoint.disconnect(this._accessPointUpdateId);
                             this._activeAccessPoint = ap;
                             this._activeAccessPointUpdateId = ap.connect('notify::strength', Lang.bind(this, function() {
-                                this.setIcon('network-wireless-signal-' + signalToIcon(ap.strength));
+                                this.setIcon('network-wireless-signal-' + signalToIcon(ap.strength) + '-symbolic');
                             }));
                         }
-                        this.setIcon('network-wireless-signal-' + signalToIcon(ap.strength));
+                        this.setIcon('network-wireless-signal-' + signalToIcon(ap.strength) + '-symbolic');
                         hasApIcon = true;
                     }
                     break;
@@ -2166,7 +2133,7 @@ const NMApplet = new Lang.Class({
                     break;
                 }
             case NMConnectionCategory.WIRED:
-                this.setIcon('network-wired');
+                this.setIcon('network-wired-symbolic');
                 break;
             case NMConnectionCategory.WWAN:
                 dev = mc._primaryDevice;
@@ -2176,7 +2143,7 @@ const NMApplet = new Lang.Class({
                 }
                 if (!dev.mobileDevice) {
                     // this can happen for bluetooth in PAN mode
-                    this.setIcon('network-cellular-connected');
+                    this.setIcon('network-cellular-connected-symbolic');
                     break;
                 }
 
@@ -2185,37 +2152,37 @@ const NMApplet = new Lang.Class({
                         this._mobileUpdateDevice.disconnect(this._mobileUpdateId);
                     this._mobileUpdateDevice = dev.mobileDevice;
                     this._mobileUpdateId = dev.mobileDevice.connect('notify::signal-quality', Lang.bind(this, function() {
-                        this.setIcon('network-cellular-signal-' + signalToIcon(dev.mobileDevice.signal_quality));
+                        this.setIcon('network-cellular-signal-' + signalToIcon(dev.mobileDevice.signal_quality) + '-symbolic');
                     }));
                 }
-                this.setIcon('network-cellular-signal-' + signalToIcon(dev.mobileDevice.signal_quality));
+                this.setIcon('network-cellular-signal-' + signalToIcon(dev.mobileDevice.signal_quality) + '-symbolic');
                 hasMobileIcon = true;
                 break;
             default:
                 // fallback to a generic connected icon
                 // (it could be a private connection of some other user)
-                this.setIcon('network-wired');
+                this.setIcon('network-wired-symbolic');
                 break;
             }
         }
 
         // update VPN indicator
         if (this._vpnConnection) {
-            let vpnIconName = 'network-vpn';
+            let vpnIconName = 'network-vpn-symbolic';
             if (this._vpnConnection.state == NetworkManager.ActiveConnectionState.ACTIVATING)
-                vpnIconName = 'network-vpn-acquiring';
+                vpnIconName = 'network-vpn-acquiring-symbolic';
 
             // only show a separate icon when we're using a wireless/3g connection
             if (mc._section == NMConnectionCategory.WIRELESS || 
                 mc._section == NMConnectionCategory.WWAN) {
-                this._secondaryIcon.icon_name = vpnIconName;
-                this._secondaryIcon.visible = true;
+                this.secondaryIcon.icon_name = vpnIconName;
+                this.secondaryIcon.show();
             } else {
                 this.setIcon(vpnIconName);
-                this._secondaryIcon.visible = false;
+                this.secondaryIcon.hide();
             }
         } else {
-            this._secondaryIcon.visible = false;
+            this.secondaryIcon.hide();
         }
 
         // cleanup stale signal connections
