@@ -52,10 +52,11 @@ const Indicator = new Lang.Class({
     Extends: PanelMenu.SystemStatusButton,
 
     _init: function() {
-        this.parent('battery-missing', _("Battery"));
+        this.parent('battery-missing-symbolic', _("Battery"));
 
         this._proxy = new PowerManagerProxy(Gio.DBus.session, BUS_NAME, OBJECT_PATH);
 
+        this._isLocked = false;
         this._deviceItems = [ ];
         this._hasPrimary = false;
         this._primaryDeviceId = null;
@@ -77,9 +78,8 @@ const Indicator = new Lang.Class({
     },
 
     setLockedState: function(locked) {
-        if (locked)
-            this.menu.close();
-        this.actor.reactive = !locked;
+        this._isLocked = locked;
+        this._syncIcon();
     },
 
     _readPrimaryDevice: function() {
@@ -150,16 +150,21 @@ const Indicator = new Lang.Class({
         }));
     },
 
-    _devicesChanged: function() {
+    _syncIcon: function() {
         let icon = this._proxy.Icon;
+        let hasIcon = false;
+
         if (icon) {
             let gicon = Gio.icon_new_for_string(icon);
             this.setGIcon(gicon);
-            this.actor.show();
-        } else {
-            this.menu.close();
-            this.actor.hide();
+            hasIcon = true;
         }
+        this.mainIcon.visible = hasIcon;
+        this.actor.visible = hasIcon && !this._isLocked;
+    },
+
+    _devicesChanged: function() {
+        this._syncIcon();
         this._readPrimaryDevice();
         this._readOtherDevices();
     }
@@ -178,7 +183,6 @@ const DeviceItem = new Lang.Class({
         this._label = new St.Label({ text: this._deviceTypeToString(device_type) });
 
         this._icon = new St.Icon({ gicon: Gio.icon_new_for_string(icon),
-                                   icon_type: St.IconType.SYMBOLIC,
                                    style_class: 'popup-menu-icon' });
 
         this._box.add_actor(this._icon);
