@@ -48,9 +48,12 @@ const UserAvatarWidget = new Lang.Class({
 
     _init: function(user, params) {
         this._user = user;
-        params = Params.parse(params, { reactive: true });
+        params = Params.parse(params, { reactive: false,
+                                        iconSize: DIALOG_ICON_SIZE,
+                                        styleClass: 'status-chooser-user-icon' });
+        this._iconSize = params.iconSize;
 
-        this.actor = new St.Bin({ style_class: 'status-chooser-user-icon',
+        this.actor = new St.Bin({ style_class: params.styleClass,
                                   track_hover: params.reactive,
                                   reactive: params.reactive });
     },
@@ -66,9 +69,8 @@ const UserAvatarWidget = new Lang.Class({
             this.actor.style = 'background-image: url("%s");'.format(iconFile);
         } else {
             this.actor.style = null;
-            this.actor.child = new St.Icon({ icon_name: 'avatar-default',
-                                             icon_type: St.IconType.SYMBOLIC,
-                                             icon_size: DIALOG_ICON_SIZE });
+            this.actor.child = new St.Icon({ icon_name: 'avatar-default-symbolic',
+                                             icon_size: this._iconSize });
         }
     }
 });
@@ -144,7 +146,7 @@ const IMStatusChooserItem = new Lang.Class({
         this._userManager = AccountsService.UserManager.get_default();
         this._user = this._userManager.get_user(GLib.get_user_name());
 
-        this._avatar = new UserAvatarWidget(this._user);
+        this._avatar = new UserAvatarWidget(this._user, { reactive: true });
         this._iconBin = new St.Button({ child: this._avatar.actor });
         this.addActor(this._iconBin);
 
@@ -164,22 +166,22 @@ const IMStatusChooserItem = new Lang.Class({
 
         let item;
 
-        item = new IMStatusItem(_("Available"), 'user-available');
+        item = new IMStatusItem(_("Available"), 'user-available-symbolic');
         this._combo.addMenuItem(item, IMStatus.AVAILABLE);
 
-        item = new IMStatusItem(_("Busy"), 'user-busy');
+        item = new IMStatusItem(_("Busy"), 'user-busy-symbolic');
         this._combo.addMenuItem(item, IMStatus.BUSY);
 
-        item = new IMStatusItem(_("Invisible"), 'user-invisible');
+        item = new IMStatusItem(_("Invisible"), 'user-invisible-symbolic');
         this._combo.addMenuItem(item, IMStatus.HIDDEN);
 
-        item = new IMStatusItem(_("Away"), 'user-away');
+        item = new IMStatusItem(_("Away"), 'user-away-symbolic');
         this._combo.addMenuItem(item, IMStatus.AWAY);
 
-        item = new IMStatusItem(_("Idle"), 'user-idle');
+        item = new IMStatusItem(_("Idle"), 'user-idle-symbolic');
         this._combo.addMenuItem(item, IMStatus.IDLE);
 
-        item = new IMStatusItem(_("Unavailable"), 'user-offline');
+        item = new IMStatusItem(_("Unavailable"), 'user-offline-symbolic');
         this._combo.addMenuItem(item, IMStatus.OFFLINE);
 
         this._combo.connect('active-item-changed',
@@ -480,19 +482,19 @@ const UserMenuButton = new Lang.Class({
         box.add(this._iconBox, { y_align: St.Align.MIDDLE, y_fill: false });
 
         let textureCache = St.TextureCache.get_default();
-        this._offlineIcon = new St.Icon({ icon_name: 'user-offline',
+        this._offlineIcon = new St.Icon({ icon_name: 'user-offline-symbolic',
                                           style_class: 'popup-menu-icon' });
-        this._availableIcon = new St.Icon({ icon_name: 'user-available',
+        this._availableIcon = new St.Icon({ icon_name: 'user-available-symbolic',
                                             style_class: 'popup-menu-icon' });
-        this._busyIcon = new St.Icon({ icon_name: 'user-busy',
+        this._busyIcon = new St.Icon({ icon_name: 'user-busy-symbolic',
                                        style_class: 'popup-menu-icon' });
-        this._invisibleIcon = new St.Icon({ icon_name: 'user-invisible',
+        this._invisibleIcon = new St.Icon({ icon_name: 'user-invisible-symbolic',
                                             style_class: 'popup-menu-icon' });
-        this._awayIcon = new St.Icon({ icon_name: 'user-away',
+        this._awayIcon = new St.Icon({ icon_name: 'user-away-symbolic',
                                        style_class: 'popup-menu-icon' });
-        this._idleIcon = new St.Icon({ icon_name: 'user-idle',
+        this._idleIcon = new St.Icon({ icon_name: 'user-idle-symbolic',
                                        style_class: 'popup-menu-icon' });
-        this._pendingIcon = new St.Icon({ icon_name: 'user-status-pending',
+        this._pendingIcon = new St.Icon({ icon_name: 'user-status-pending-symbolic',
                                           style_class: 'popup-menu-icon' });
 
         this._accountMgr.connect('most-available-presence-changed',
