@@ -172,8 +172,7 @@ show_capslock_feedback (StEntry *entry)
     {
       ClutterActor *icon = g_object_new (ST_TYPE_ICON,
                                          "style-class", "capslock-warning",
-                                         "icon-type", ST_ICON_SYMBOLIC,
-                                         "icon-name", "dialog-warning",
+                                         "icon-name", "dialog-warning-symbolic",
                                          NULL);
 
       st_entry_set_secondary_icon (entry, icon);
@@ -285,8 +284,7 @@ st_entry_navigate_focus (StWidget         *widget,
 
   if (from == priv->entry)
     return FALSE;
-  else if (clutter_actor_get_reactive (CLUTTER_ACTOR (widget)) &&
-           st_widget_get_can_focus (widget))
+  else if (st_widget_get_can_focus (widget))
     {
       clutter_actor_grab_key_focus (priv->entry);
       return TRUE;
