@@ -22,6 +22,7 @@
 #include "config.h"
 
 #include "st-texture-cache.h"
+#include "st-private.h"
 #include <gtk/gtk.h>
 #include <string.h>
 #include <glib.h>
@@ -967,9 +968,6 @@ load_gicon_with_colors (StTextureCache    *cache,
  * icon isn't loaded already, the texture will be filled
  * asynchronously.
  *
- * This will load @icon as a full-color icon; if you want a symbolic
- * icon, you must use st_texture_cache_load_icon_name().
- *
  * Return Value: (transfer none): A new #ClutterActor for the icon, or %NULL if not found
  */
 ClutterActor *
@@ -1123,69 +1121,15 @@ st_texture_cache_load_sliced_image (StTextureCache    *cache,
   return actor;
 }
 
-/**
- * StIconType:
- * @ST_ICON_SYMBOLIC: a symbolic (ie, mostly monochrome) icon
- * @ST_ICON_FULLCOLOR: a full-color icon
- *
- * Describes what style of icon is desired in a call to
- * st_texture_cache_load_icon_name() or st_texture_cache_load_gicon().
- * Use %ST_ICON_SYMBOLIC for symbolic icons (eg, for the panel and
- * much of the rest of the shell chrome) or %ST_ICON_FULLCOLOR for a
- * full-color icon.
- */
-
-/* generates names like g_themed_icon_new_with_default_fallbacks(),
- * but *only* symbolic names
- */
-static char **
-symbolic_names_for_icon (const char *name)
-{
-  char **parts, **names;
-  int i, numnames;
-
-  parts = g_strsplit (name, "-", -1);
-  numnames = g_strv_length (parts);
-  names = g_new (char *, numnames + 1);
-  for (i = 0; parts[i]; i++)
-    {
-      if (i == 0)
-        {
-          names[i] = g_strdup_printf ("%s-symbolic", parts[i]);
-        }
-      else
-        {
-          names[i] = g_strdup_printf ("%.*s-%s-symbolic",
-                                      (int) (strlen (names[i - 1]) - strlen ("-symbolic")),
-                                      names[i - 1], parts[i]);
-        }
-    }
-  names[i] = NULL;
-
-  g_strfreev (parts);
-
-  /* need to reverse here, because longest (most specific)
-     name has to come first */
-  for (i = 0; i < (numnames / 2); i++) {
-    char *tmp = names[i];
-    names[i] = names[numnames - i - 1];
-    names[numnames - i - 1] = tmp;
-  }
-
-  return names;
-}
-
 /**
  * st_texture_cache_load_icon_name:
  * @cache: The texture cache instance
  * @theme_node: (allow-none): a #StThemeNode
  * @name: Name of a themed icon
- * @icon_type: the type of icon to load
  * @size: Size of themed icon
  *
- * Load a themed icon into a texture. See the #StIconType documentation
- * for an explanation of how @icon_type affects the returned icon. The
- * colors used for symbolic icons are derived from @theme_node.
+ * Load a themed icon into a texture. The colors used for symbolic
+ * icons are derived from @theme_node.
  *
  * Return Value: (transfer none): A new #ClutterTexture for the icon
  */
@@ -1193,50 +1137,23 @@ ClutterActor *
 st_texture_cache_load_icon_name (StTextureCache    *cache,
                                  StThemeNode       *theme_node,
                                  const char        *name,
-                                 StIconType         icon_type,
                                  gint               size)
 {
   ClutterActor *texture;
   GIcon *themed;
-  char **names;
 
-  g_return_val_if_fail (!(icon_type == ST_ICON_SYMBOLIC && theme_node == NULL), NULL);
+  themed = g_themed_icon_new_with_default_fallbacks (name);
+  texture = load_gicon_with_colors (cache, themed, size,
+                                    theme_node ? st_theme_node_get_icon_colors (theme_node) : NULL);
+  g_object_unref (themed);
 
-  switch (icon_type)
+  if (texture == NULL)
     {
-    case ST_ICON_SYMBOLIC:
-      names = symbolic_names_for_icon (name);
-      themed = g_themed_icon_new_from_names (names, -1);
-      g_strfreev (names);
-      texture = load_gicon_with_colors (cache, themed, size,
-                                        st_theme_node_get_icon_colors (theme_node));
-      g_object_unref (themed);
-      if (texture == NULL)
-        {
-          /* We don't have an equivalent of image-missing
-           * for the symbolic icon theme, so just create a blank
-           * actor. */
-          texture = (ClutterActor *) create_default_texture ();
-          clutter_actor_set_size (texture, size, size);
-        }
-
-      return texture;
-      break;
-    case ST_ICON_FULLCOLOR:
-      themed = g_themed_icon_new_with_default_fallbacks (name);
-      texture = load_gicon_with_colors (cache, themed, size, NULL);
-      g_object_unref (themed);
-      if (texture == NULL)
-        {
-          themed = g_themed_icon_new ("image-missing");
-          texture = load_gicon_with_colors (cache, themed, size, NULL);
-          g_object_unref (themed);
-        }
-      return texture;
-      break;
-    default:
-      g_assert_not_reached ();
+      texture = (ClutterActor *) create_default_texture ();
+      clutter_actor_set_size (texture, size, size);
     }
+
+  return texture;
 }
 
 /**
